@@ -3,19 +3,25 @@
 
 set -e
 
-readonly SWIFTTAG=5.10.1
-readonly YAMS_VERSION=5.0.1
-readonly SWIFT_ARGUMENT_PARSER_VERSION=1.2.3
+readonly SWIFTTAG=6.1.3
+readonly YAMS_VERSION=5.0.6
+readonly SWIFT_ARGUMENT_PARSER_VERSION=1.4.0
 readonly SWIFT_CRYPTO_VERSION=3.0.0
-readonly SWIFT_ATOMICS_VERSION=1.0.2
-readonly SWIFT_COLLECTIONS_VERSION=1.0.5
-readonly SWIFT_NUMERICS_VERSION=1.0.1
-readonly SWIFT_SYSTEM_VERSION=1.1.1
-readonly SWIFT_NIO_VERSION=2.31.2
-readonly SWIFT_NIO_SSL_VERSION=2.15.0
-readonly SWIFT_FORMAT_VERSION=510.1.0
+readonly SWIFT_ATOMICS_VERSION=1.2.0
+readonly SWIFT_COLLECTIONS_VERSION=1.1.3
+readonly SWIFT_NUMERICS_VERSION=1.0.2
+readonly SWIFT_SYSTEM_VERSION=1.3.0
+readonly SWIFT_NIO_VERSION=2.65.0
+#readonly SWIFT_NIO_SSL_VERSION=2.15.0
 readonly SWIFT_CERTIFICATES_VERSION=1.0.1
 readonly SWIFT_ASN1_VERSION=1.0.0
+#readonly WASMKIT_VERSION=0.1.2
+#readonly WASI_VERSION=22
+readonly SWIFT_FORMAT_VERSION=601.0.0
+readonly SWIFT_TOOLCHAIN_SQLITE_VERSION=1.0.1
+readonly SWIFT_ASYNC_ALGORITHMS_VERSION=1.0.1
+readonly SWIFT_LOG_VERSION=1.5.4
+
 
 if [ -f "swiftlang_$SWIFTTAG.orig.tar.xz" ];
 then
@@ -63,6 +69,28 @@ mkdir swift-corelibs-foundation
 tar -C swift-corelibs-foundation -xzf ../swiftlang_$SWIFTTAG.orig-swift-corelibs-foundation.tar.gz --strip-components=1
 
 
+if [ -f "../swiftlang_$SWIFTTAG.orig-swift-foundation-icu.tar.gz" ];
+then
+    echo "Found existing swiftlang_$SWIFTTAG.orig-swift-foundation-icu.tar.gz"
+else
+    wget https://github.com/swiftlang/swift-foundation-icu/archive/swift-$SWIFTTAG-RELEASE.tar.gz
+    mv -f swift-$SWIFTTAG-RELEASE.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-foundation-icu.tar.gz
+fi
+mkdir swift-foundation-icu
+tar -C swift-foundation-icu -xzf ../swiftlang_$SWIFTTAG.orig-swift-foundation-icu.tar.gz --strip-components=1
+
+
+if [ -f "../swiftlang_$SWIFTTAG.orig-swift-foundation.tar.gz" ];
+then
+    echo "Found existing swiftlang_$SWIFTTAG.orig-swift-foundation.tar.gz"
+else
+    wget https://github.com/swiftlang/swift-foundation/archive/swift-$SWIFTTAG-RELEASE.tar.gz
+    mv -f swift-$SWIFTTAG-RELEASE.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-foundation.tar.gz
+fi
+mkdir swift-foundation
+tar -C swift-foundation -xzf ../swiftlang_$SWIFTTAG.orig-swift-foundation.tar.gz --strip-components=1
+
+
 if [ -f "../swiftlang_$SWIFTTAG.orig-swift-integration-tests.tar.gz" ];
 then
     echo "Found existing swiftlang_$SWIFTTAG.orig-swift-integration-tests.tar.gz"
@@ -356,15 +384,15 @@ unzip -q ../swiftlang_$SWIFTTAG.orig-swift-nio.zip
 mv swift-nio-$SWIFT_NIO_VERSION swift-nio
 
 
-if [ -f "../swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip" ];
-then
-    echo "Found existing swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip"
-else
-    wget https://github.com/apple/swift-nio-ssl/archive/refs/tags/$SWIFT_NIO_SSL_VERSION.zip
-    mv -f $SWIFT_NIO_SSL_VERSION.zip ../swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip
-fi
-unzip -q ../swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip
-mv swift-nio-ssl-$SWIFT_NIO_SSL_VERSION swift-nio-ssl
+#if [ -f "../swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip" ];
+#then
+    #echo "Found existing swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip"
+#else
+    #wget https://github.com/apple/swift-nio-ssl/archive/refs/tags/$SWIFT_NIO_SSL_VERSION.zip
+    #mv -f $SWIFT_NIO_SSL_VERSION.zip ../swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip
+#fi
+#unzip -q ../swiftlang_$SWIFTTAG.orig-swift-nio-ssl.zip
+#mv swift-nio-ssl-$SWIFT_NIO_SSL_VERSION swift-nio-ssl
 
 if [ -f "../swiftlang_$SWIFTTAG.orig-swift-format.tar.gz" ];
 then
@@ -406,6 +434,81 @@ fi
 mkdir swift-asn1
 tar -C swift-asn1 -xzf ../swiftlang_$SWIFTTAG.orig-swift-asn1.tar.gz --strip-components=1
 
+#if [ -f "../swiftlang_$SWIFTTAG.orig-wasi-libc.tar.gz" ];
+#then
+    #echo "Found existing swiftlang_$SWIFTTAG.orig-wasi-libc.tar.gz"
+#else
+    #wget https://github.com/WebAssembly/wasi-libc/archive/refs/tags/wasi-sdk-$WASI_VERSION.tar.gz
+    #mv -f wasi-sdk-$WASI_VERSION.tar.gz ../swiftlang_$SWIFTTAG.orig-wasi-libc.tar.gz
+#fi
+#mkdir wasi-libc
+#tar -C wasi-libc -xzf ../swiftlang_$SWIFTTAG.orig-wasi-libc.tar.gz --strip-components=1
+
+
+#if [ -f "../swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz" ];
+#then
+    #echo "Found existing swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz"
+#else
+    #wget https://github.com/swiftwasm/WasmKit/archive/refs/tags/$WASMKIT_VERSION.tar.gz
+    #mv -f $WASMKIT_VERSION.tar.gz ../swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz
+#fi
+#mkdir wasmkit
+#tar -C wasmkit -xzf ../swiftlang_$SWIFTTAG.orig-wasmkit.tar.gz --strip-components=1
+
+
+if [ -f "../swiftlang_$SWIFTTAG.orig-swift-testing.tar.gz" ];
+then
+    echo "Found existing swiftlang_$SWIFTTAG.orig-swift-testing.tar.gz"
+else
+    wget https://github.com/swiftlang/swift-testing/archive/refs/tags/swift-$SWIFTTAG-RELEASE.tar.gz
+    mv -f swift-$SWIFTTAG-RELEASE.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-testing.tar.gz
+fi
+mkdir swift-testing
+tar -C swift-testing -xzf ../swiftlang_$SWIFTTAG.orig-swift-testing.tar.gz --strip-components=1
+
+if [ -f "../swiftlang_$SWIFTTAG.orig-swift-toolchain-sqlite.tar.gz" ];
+then
+    echo "Found existing swiftlang_$SWIFTTAG.orig-swift-toolchain-sqlite.tar.gz"
+else
+    wget https://github.com/swiftlang/swift-toolchain-sqlite/archive/refs/tags/$SWIFT_TOOLCHAIN_SQLITE_VERSION.tar.gz
+    mv -f $SWIFT_TOOLCHAIN_SQLITE_VERSION.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-toolchain-sqlite.tar.gz
+fi
+mkdir swift-toolchain-sqlite
+tar -C swift-toolchain-sqlite -xzf ../swiftlang_$SWIFTTAG.orig-swift-toolchain-sqlite.tar.gz --strip-components=1
+
+if [ -f "../swiftlang_$SWIFTTAG.orig-swift-sdk-generator.tar.gz" ];
+then
+    echo "Found existing swiftlang_$SWIFTTAG.orig-swift-sdk-generator.tar.gz"
+else
+    wget https://github.com/swiftlang/swift-sdk-generator/archive/refs/tags/swift-$SWIFTTAG-RELEASE.tar.gz
+    mv -f swift-$SWIFTTAG-RELEASE.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-sdk-generator.tar.gz
+fi
+mkdir swift-sdk-generator
+tar -C swift-sdk-generator -xzf ../swiftlang_$SWIFTTAG.orig-swift-sdk-generator.tar.gz --strip-components=1
+
+
+if [ -f "../swiftlang_$SWIFTTAG.orig-swift-async-algorithms.tar.gz" ];
+then
+    echo "Found existing swiftlang_$SWIFTTAG.orig-swift-async-algorithms.tar.gz"
+else
+    wget https://github.com/apple/swift-async-algorithms/archive/refs/tags/$SWIFT_ASYNC_ALGORITHMS_VERSION.tar.gz
+    mv -f $SWIFT_ASYNC_ALGORITHMS_VERSION.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-async-algorithms.tar.gz
+fi
+mkdir swift-async-algorithms
+tar -C swift-async-algorithms -xzf ../swiftlang_$SWIFTTAG.orig-swift-async-algorithms.tar.gz --strip-components=1
+
+if [ -f "../swiftlang_$SWIFTTAG.orig-swift-log.tar.gz" ];
+then
+    echo "Found existing swiftlang_$SWIFTTAG.orig-swift-log.tar.gz"
+else
+    wget https://github.com/apple/swift-log/archive/refs/tags/$SWIFT_LOG_VERSION.tar.gz
+    mv -f $SWIFT_LOG_VERSION.tar.gz ../swiftlang_$SWIFTTAG.orig-swift-log.tar.gz
+fi
+mkdir swift-log
+tar -C swift-log -xzf ../swiftlang_$SWIFTTAG.orig-swift-log.tar.gz --strip-components=1
+
+
+
 cd ..
 
 # Build "orig" tarball of all sources
